/******************************************************************************************
 * Repository: Conhos vscode
 * File name: lib.ts
 * Author: Sergey Kolmiller
 * Email: <kolserdav@conhos.ru>
 * License: MIT
 * License text: See LICENSE file
 * Copyright: kolserdav, All rights reserved (c)
 * Create Date: Tue Sep 10 2024 16:42:55 GMT+0700 (Krasnoyarsk Standard Time)
 ******************************************************************************************/
import type { CheckConfigResult, CompletionItem, Config, ConfigFile, Deploy, DeployData, DockerHubCheckImageArgs, DockerHubCheckImageResult, Git, GitType, ParsedGitRepo, Port, PortStatic, Position, Range, Server, ServiceSize, ServiceType, ServiceTypeCommon, ServiceTypeCommonPublic, ServiceTypeCustom, UpdateConfig, Volumes } from '../index';
interface CompletionData {
    detail: string;
    documentation: string;
}
type ConfigServerDefault<O extends Server> = {
    [K in keyof Required<O>]: {
        required: undefined extends O[K] ? false : true;
        value: Required<O[K]>;
    } & CompletionData;
};
declare function createServerDefault<O extends Server>(config: ConfigServerDefault<O>): ConfigServerDefault<O>;
type ConfigStaticDefault<O extends PortStatic> = {
    [K in keyof Required<O>]: {
        required: undefined extends O[K] ? false : true;
        value: Required<O[K]>;
    } & CompletionData;
};
declare function createStaticDefault<O extends PortStatic>(config: ConfigStaticDefault<O>): ConfigStaticDefault<O>;
type ConfigUpdateConfigDefault<O extends UpdateConfig> = {
    [K in keyof Required<O>]: {
        required: undefined extends O[K] ? false : true;
        value: Required<O[K]>;
    } & CompletionData;
};
declare function createUpdateConfigDefault<O extends UpdateConfig>(config: ConfigUpdateConfigDefault<O>): ConfigUpdateConfigDefault<O>;
type ConfigDeployDefault<O extends Deploy> = {
    [K in keyof Required<O>]: {
        required: undefined extends O[K] ? false : true;
        value: K extends 'update_config' ? Required<ReturnType<typeof createUpdateConfigDefault>> : Required<O[K]>;
    } & CompletionData;
};
declare function createDeployDefault<O extends Deploy>(config: ConfigDeployDefault<O>): ConfigDeployDefault<O>;
type ConfigPortsDefault<O extends Port> = {
    [K in keyof Required<O>]: {
        required: undefined extends O[K] ? false : true;
        value: K extends 'static' ? Required<ReturnType<typeof createStaticDefault>> : Required<O[K]>;
    } & CompletionData;
};
declare function createPortsDefault<O extends Port>(config: ConfigPortsDefault<O>): ConfigPortsDefault<O>;
type ConfigGitDefault<O extends Git> = {
    [K in keyof Required<O>]: {
        required: undefined extends O[K] ? false : true;
        value: Required<O[K]>;
    } & CompletionData;
};
declare function createGitDefault<O extends Git>(config: ConfigGitDefault<O>): ConfigGitDefault<O>;
type ConfigFileDefault<T extends keyof ConfigFile> = {
    name: T;
    required: undefined extends ConfigFile[T] ? false : true;
    value: T extends 'server' ? Required<ReturnType<typeof createServerDefault>> : ConfigFile[T];
} & CompletionData;
type ConfigServiceDefault<O extends ConfigFile['services'][0]> = {
    [K in keyof Required<O>]: {
        required: undefined extends O[K] ? false : true;
        value: K extends 'git' ? Required<ReturnType<typeof createGitDefault>> : K extends 'ports' ? Required<ReturnType<typeof createPortsDefault>> : K extends 'deploy' ? Required<ReturnType<typeof createDeployDefault>> : Required<O[K]>;
    } & CompletionData;
};
export declare const CONFIG_DEFAULT: {
    name: ConfigFileDefault<"name">;
    server: ConfigFileDefault<"server">;
    services: {
        required: boolean;
        value: ConfigServiceDefault<{
            active: boolean;
            image: ServiceType;
            size: ServiceSize;
            version: string;
            entrypoint?: string[];
            no_restart?: boolean;
            pwd?: string;
            git?: Git;
            exclude?: string[];
            command?: string;
            ports?: Port[];
            volumes?: string[];
            depends_on?: string[];
            domains?: import("../index").NewDomains["domains"];
            environment?: string[];
            deploy?: Deploy;
        }>;
        detail: string;
        documentation: string;
    };
};
export declare function computeCostService({ serviceSize, replicas }: {
    serviceSize: ServiceSize;
    replicas: number;
}, { sizes, baseCost, baseValue }: Omit<DeployData, 'services' | 'nodePublic'>): {
    month: number;
    hour: number;
    minute: number;
} | null;
export declare const isCustomService: (type: ServiceType) => ServiceTypeCustom | null;
export declare function isDomain(domain: string): boolean;
export declare const isCommonService: (type: ServiceType) => ServiceTypeCommon | null;
export declare const findEnvironmentValue: (environment: string[], name: string) => string | null;
export declare const checkRecord: (record: Record<string, string | null>, name: string) => boolean;
export declare const parseEnvironmentVariable: (variable: string) => {
    name: string;
    value: string;
} | null;
export declare const checkEnvironmentRequired: (name: string) => boolean;
export declare const isCommonServicePublic: (type: ServiceType) => null | ServiceTypeCommonPublic;
export declare const getServiceBySize: (sizes: DeployData["sizes"], size: ServiceSize) => {
    name: string;
    memory: {
        name: string;
        value: number;
    };
    cpus: number;
    storage: string;
    ports: number;
} | undefined;
interface GetServicePosition<T extends keyof ConfigFile['services'][0], D extends ConfigFile['services'][0][T]> {
    name: string;
    property: T | null;
    value: D extends Array<infer U> ? Partial<U> : Partial<D> | null;
}
export declare function getPosition<T extends keyof ConfigFile, K extends keyof ConfigFile['services'][0], D extends ConfigFile['services'][0][K]>({ configText, config, field, service, }: {
    configText: string;
    config: ConfigFile;
    field: T | null;
    service: T extends 'services' ? GetServicePosition<K, D> : null;
}): CheckConfigResult['position'];
export declare function checkParseError(text: string): CheckConfigResult['position'];
export declare function checkConfig({ config, configText }: {
    config: ConfigFile;
    configText: string;
}, { deployData }: {
    deployData: DeployData;
}): Promise<CheckConfigResult[]>;
export declare function checkGitType(url: string): GitType | null;
export declare function cleanGitPostfix(url: string): string;
export declare function parseGitUrl(url: string): ParsedGitRepo | null;
export declare function clearRelPath(url: string): string;
export declare function changeConfigFileVolumes({ config }: {
    config: ConfigFile;
}, volumes: Volumes): Promise<{
    config: ConfigFile;
    error: string | null;
}>;
export declare function createCompletionItems(config: {
    value: Config;
}, level?: number, parent?: string): CompletionItem[];
export declare function getParentProperty({ text, currentLevel, currentLineIndex, }: {
    text: string;
    currentLevel: number;
    currentLineIndex: number;
}): string | null;
export declare function getCurrentLevel(currentLine: string): number;
export declare function getWordRangeAtPosition(text: string, position: Position): Range | null;
export declare function checkCompletionWrapper({ parentEl, currentLevel, lineTextClear, }: {
    parentEl: string | null;
    currentLevel: number;
    lineTextClear: string | undefined;
}): (item: CompletionItem) => boolean;
/**
 * @see {isLastStreamMessage}
 */
export declare function createLastStreamMessage(code: number | null): string;
/**
 * @see {createLastStreamMessage}
 */
export declare function isLastStreamMessage(message: string): boolean;
export declare function checkCustomImage({ image, }: DockerHubCheckImageArgs): Promise<DockerHubCheckImageResult>;
export {};
